==> cdktf-cdktf-provider-google_beta-3.0.1.tar.gz: package/lib/data-google-tags-tag-value/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleTagsTagValueConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_tags_tag_value#parent DataGoogleTagsTagValue#parent}
    */
    readonly parent: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_tags_tag_value#short_name DataGoogleTagsTagValue#short_name}
    */
    readonly shortName: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/d/google_tags_tag_value google_tags_tag_value}
*/
export declare class DataGoogleTagsTagValue extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_tags_tag_value";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/d/google_tags_tag_value google_tags_tag_value} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleTagsTagValueConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleTagsTagValueConfig);
    get createTime(): string;
    get description(): string;
    get id(): string;
    get name(): string;
    get namespacedName(): string;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _shortName?;
    get shortName(): string;
    set shortName(value: string);
    get shortNameInput(): string | undefined;
    get updateTime(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google_beta-7.0.0.tar.gz: package/lib/data-google-tags-tag-value/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleTagsTagValueConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_tags_tag_value#parent DataGoogleTagsTagValue#parent}
    */
    readonly parent: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_tags_tag_value#short_name DataGoogleTagsTagValue#short_name}
    */
    readonly shortName: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_tags_tag_value google_tags_tag_value}
*/
export declare class DataGoogleTagsTagValue extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_tags_tag_value";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_tags_tag_value google_tags_tag_value} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleTagsTagValueConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleTagsTagValueConfig);
    get createTime(): string;
    get description(): string;
    get id(): string;
    get name(): string;
    get namespacedName(): string;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _shortName?;
    get shortName(): string;
    set shortName(value: string);
    get shortNameInput(): string | undefined;
    get updateTime(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
